@@ -268,3 +268,25 @@ class ArticleCollectionOrder(models.Model):
     article_collection = models.ForeignKey(
         ArticleCollection, related_name="contained_articles", on_delete=models.CASCADE)
     order = models.IntegerField()
+
+
+class FeatureOption(RippleBase):
+
+    name = models.CharField(max_length=200)
+    description = models.CharField(max_length=200, blank=True, default='')
+    active = models.BooleanField(default=False)
+
+    def __str__(self):
+        return self.name
+
+
+class FeatureUrl(RippleBase):
+
+    description = models.CharField(max_length=200, blank=True, default='')
+    feature = models.ForeignKey(
+        FeatureOption, related_name='urls', on_delete=models.CASCADE)
+    regex = models.TextField(max_length=800)
+
+    def __str__(self):
+        return "{} {}".format(self.feature.name, self.regex[:20])
+
